@@ -20,15 +20,15 @@ class SocketHandler:
         self.reconnectTime = 180
         self.socket_thread = None
 
-    async def bot(self):
-        await self.run()
+    async def run(self):
+        await self.connect()
         while True:
             if self.active:
                 await asyncio.sleep(self.reconnectTime)
                 if self.debug is True:
                     print(f"[socket][reconnect_handler] Reconnecting Socket")
                 await self.close()
-                await self.run()
+                await self.connect()
 
     async def handle_message(self, data):
         if self.debug is True:
@@ -46,7 +46,7 @@ class SocketHandler:
 
         self.socket.send(data)
 
-    async def run(self):
+    async def connect(self):
         try:
             if self.client.sid is None:
                 return
@@ -177,7 +177,6 @@ class Callbacks:
 
     def event(self, type):
         def register_handler(handler):
-            print(f"pruebas: {handler}")
             if type in self.handlers:
                 self.handlers[type].append(handler)
             else:
